@@ -15,17 +15,7 @@ class ContentType(Enum):
 
 class ApiBase(object):
   def __init__(self, additional_headers=None):
-    self.__start_debugger()
     self.__define_headers(additional_headers)
-    
-  def __start_debugger(self):
-    self.logging_level = None
-    try:
-      self.cph = ConfigPropertiesHelper()
-      self.logging_level = self.cph.get_property_value('SELF', 'self.logging.level')
-    except:
-      logging.warning('Logging level not found in config file')
-      pass
   
   def __define_headers(self, additional_headers=None):
     self.headers = { 
@@ -45,39 +35,37 @@ class ApiBase(object):
             res.raise_for_status() # Verifica se ocorreu algum erro HTTP
             return res
         except (ConnectionError, ChunkedEncodingError) as e:
+            logging.error(e)
             logging.error(f"Connection error occurred: {e}. Retrying {attempt + 1}/{max_retries}...")
             if attempt == max_retries - 1:
                 raise # Lança a exceção se o limite de tentativas for atingido
         except requests.exceptions.RequestException as e:
+            logging.error(e)
             logging.error(f"An error occurred: {e}")
             raise # Lança qualquer outra exceção que não for de conexão
 
   def call_request(self, http_method:HTTPMethod, request_url, params=None, payload=None, content_type:ContentType=ContentType.APPLICATION_JSON):
     try:
-      if not(self.logging_level is None) and self.logging_level == 'DEBUG':
-        logging.info(f'{str(http_method).upper()} url:')
-        logging.info(request_url)
+      logging.info(f'{str(http_method).upper()} url:')
+      logging.info(request_url)
 
       self.headers['Content-Type'] = content_type.value
       
-      if not(self.logging_level is None) and self.logging_level == 'DEBUG':
-        logging.info(f'{str(http_method).upper()} headers:')
-        logging.info(jsonpickle.encode(self.headers))
+      logging.info(f'{str(http_method).upper()} headers:')
+      logging.info(jsonpickle.encode(self.headers))
 
       # Verifica se há parâmetros a serem enviados na URL
       if not params is None:
-        if not(self.logging_level is None) and self.logging_level == 'DEBUG':
-          logging.info(f'{str(http_method).upper()} params:')
-          logging.info(jsonpickle.encode(params))
+        logging.info(f'{str(http_method).upper()} params:')
+        logging.info(jsonpickle.encode(params))
 
       # Log do payload (apenas se for POST ou PUT)
       if not payload is None:
-        if not(self.logging_level is None) and self.logging_level == 'DEBUG':
-          logging.info(f'{str(http_method).upper()} payload:')
-          if content_type == ContentType.APPLICATION_JSON:
-            logging.info(jsonpickle.encode(payload))
-          else:
-            logging.info(payload)
+        logging.info(f'{str(http_method).upper()} payload:')
+        if content_type == ContentType.APPLICATION_JSON:
+          logging.info(jsonpickle.encode(payload))
+        else:
+          logging.info(payload)
 
       # Configuração dos parâmetros para requisição
       req_args = {
@@ -95,9 +83,8 @@ class ApiBase(object):
         else:
           req_args['data'] = payload
       
-      if not(self.logging_level is None) and self.logging_level == 'DEBUG':
-        logging.info(f'request args:')
-        logging.info(req_args)
+      logging.info(f'request args:')
+      logging.info(req_args)
 
       res = self.__make_request(req_args)
       
@@ -116,9 +103,8 @@ class ApiBase(object):
         
       res = res.content.decode('utf-8')
 
-      if not(self.logging_level is None) and self.logging_level == 'DEBUG':
-        logging.info(f'{str(http_method).upper()} response:')
-        logging.info(jsonpickle.encode(res))
+      logging.info(f'{str(http_method).upper()} response:')
+      logging.info(jsonpickle.encode(res))
       
       return res
     except UnavailableException as e:
